# stylelens-object


## Setup for DB connection
```bash
export DB_HOST={your_db_host_url}
export DB_PORT={your_db_port_url}
export DB_NAME={your_db_name}
export DB_USER={your_db_user}
export DB_PASSWORD={your_db_password}
```
